-----------------
Alice Bob QA
-----------------

.. literalinclude:: ../../../../../examples/user/alice_bob_qa.py
    :caption: See `alice_bob_qa.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/alice_bob_qa.py>`_ on GitHub.

-----------------
Alice Bob Talk
-----------------

.. literalinclude:: ../../../../../examples/user/alice_bob_talk.py
    :caption: See `alice_bob_talk.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/alice_bob_talk.py>`_ on GitHub.

-------------------
Complete My Code
-------------------

.. literalinclude:: ../../../../../examples/user/complete_my_code.py
    :caption: See `complete_my_code.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/complete_my_code.py>`_ on GitHub.

-------------------
Country Capital QA
-------------------

.. literalinclude:: ../../../../../examples/user/country_capital_qa.py
    :caption: See `country_capital_qa.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/country_capital_qa.py>`_ on GitHub.

-----------------
Explain my Code
-----------------

.. literalinclude:: ../../../../../examples/user/explain_my_code.py
    :caption: See `explain_my_code.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/explain_my_code.py>`_ on GitHub.

-----------------
Generate with moderation
-----------------

.. literalinclude:: ../../../../../examples/user/generate_with_moderation.py
    :caption: See `generate_with_moderation.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/generate_with_moderation.py>`_ on GitHub.

-----------------
Grid search params
-----------------

.. literalinclude:: ../../../../../examples/user/grid_search_params_greeating.py
    :caption: See `grid_search_params_greeating.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/grid_search_params_greeating.py>`_ on GitHub.

-----------------
History
-----------------

.. literalinclude:: ../../../../../examples/user/history.py
    :caption: See `history.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/history.py>`_ on GitHub.

-----------------
Many Greetings
-----------------

.. literalinclude:: ../../../../../examples/user/many_greetings.py
    :caption: See `many_greetings.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/many_greetings.py>`_ on GitHub.

-----------------
Model utils
-----------------

.. literalinclude:: ../../../../../examples/user/model_utils.py
    :caption: See `model_utils.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/model_utils.py>`_ on GitHub.

-----------------
Self reflection
-----------------

.. literalinclude:: ../../../../../examples/user/self_reflection.py
    :caption: See `self_reflection.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/self_reflection.py>`_ on GitHub.

-----------------
Streaming
-----------------

.. literalinclude:: ../../../../../examples/user/streaming.py
    :caption: See `streaming.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/streaming.py>`_ on GitHub.

-----------------
Tokenize
-----------------

.. literalinclude:: ../../../../../examples/user/tokenize_sync.py
    :caption: See `tokenize_sync.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/tokenize_sync.py>`_ on GitHub.
